import braintree
from django.conf import settings
from django.test.signals import setting_changed
from django.dispatch import receiver
from django.core.exceptions import ImproperlyConfigured


def configure():
    """(Re-)configure Braintree from the Django settings.

    :raises django.core.exceptions.ImproperlyConfigured:
        if one of the required settings are not set.
    """

    if not hasattr(settings, 'BRAINTREE_ENVIRONMENT'):
        raise ImproperlyConfigured(
            'No Braintree environment configured for the application. Please '
            'set the `BRAINTREE_ENVIRONMENT` setting'
        )
    if not hasattr(settings, 'BRAINTREE_MERCHANT_ID'):
        raise ImproperlyConfigured(
            'No Braintree merchant ID configured for the application. Please '
            'set the `BRAINTREE_MERCHANT_ID` setting'
        )
    if not hasattr(settings, 'BRAINTREE_PUBLIC_KEY'):
        raise ImproperlyConfigured(
            'No Braintree public key configured for the application. Please '
            'set the `BRAINTREE_PUBLIC_KEY` setting'
        )
    if not hasattr(settings, 'BRAINTREE_PRIVATE_KEY'):
        raise ImproperlyConfigured(
            'No Braintree private key configured for the application. Please '
            'set the `BRAINTREE_PRIVATE_KEY` setting'
        )

    braintree.Configuration.configure(settings.BRAINTREE_ENVIRONMENT,
                                      settings.BRAINTREE_MERCHANT_ID,
                                      settings.BRAINTREE_PUBLIC_KEY,
                                      settings.BRAINTREE_PRIVATE_KEY)
    braintree.Configuration.use_unsafe_ssl = \
        getattr(settings, 'BRAINTREE_USE_UNSAFE_SSL', False)


@receiver(setting_changed)
def setting_changed_callback(sender, **kwargs):
    """Reconfigure Braintree when settings are changed during testing.
    """

    configure()


configure()



from setuptools import setup

setup(
    name='djbraintree',
    version='0.1.0',
    description='Braintree for Django',
    keywords='django, braintree',
    author='Nick Bruun <nick@bruun.co>',
    author_email='nick@bruun.co',
    url='https://github.com/iconfinder/djbraintree',
    license='BSD License',
    packages=['djbraintree'],
    zip_safe=False,
    install_requires=['braintree', 'django'],
    include_package_data=True,
    test_suite='runtests.runtests',
    tests_require=['nose'],
    classifiers=[
        'Programming Language :: Python', 
        'Programming Language :: Python :: 2.6', 
        'Programming Language :: Python :: 2.7', 
        'Programming Language :: Python :: 3', 
        'Programming Language :: Python :: 3.2', 
        'License :: OSI Approved :: BSD License', 
        'Topic :: Software Development :: Libraries :: Python Modules', 
        'Framework :: Django', 
        'Environment :: Web Environment', 
    ], 
)



from django.conf import settings


def braintree_client_side_encryption_key(request):
    return {
        'BRAINTREE_CLIENT_SIDE_ENCRYPTION_KEY':
        getattr(settings, 'BRAINTREE_CLIENT_SIDE_ENCRYPTION_KEY', None),
    }
